============
Installation
============

At the command line::

    $ easy_install AppDynamicsRESTx

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv AppDynamicsRESTx
    $ pip install AppDynamicsRESTx
